# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-08-10 10:46
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_track', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='usertrackrecord',
            name='info',
            field=models.TextField(blank=True, null=True, verbose_name='\u8be6\u60c5'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-10-31 07:33
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_track', '0003_auto_20181031_1530'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='usertrackrecord',
            options={'ordering': ['-created_at'], 'permissions': (('add_user_leave', '\u53ef\u4ee5\u6dfb\u52a0\u5b66\u751f\u8bf7\u5047\u7c7b\u8db3\u8ff9'), ('view_user_leave', '\u53ef\u4ee5\u67e5\u770b\u5b66\u751f\u8bf7\u5047\u7c7b\u8db3\u8ff9'), ('add_crm_fee', '\u53ef\u4ee5\u6dfb\u52a0\u7f34\u8d39\u7c7b\u8db3\u8ff9'), ('view_crm_fee', '\u53ef\u4ee5\u67e5\u770b\u7f34\u8d39\u7c7b\u8db3\u8ff9'), ('add_crm_referral', '\u53ef\u4ee5\u6dfb\u52a0\u8f6c\u4ecb\u7c7b\u8db3\u8ff9'), ('view_crm_referral', '\u53ef\u4ee5\u67e5\u770b\u8f6c\u4ecb\u7c7b\u8db3\u8ff9'), ('add_track_other', '\u53ef\u4ee5\u6dfb\u52a0\u5176\u4ed6\u7c7b\u8db3\u8ff9'), ('view_track_other', '\u53ef\u4ee5\u67e5\u770b\u5176\u4ed6\u7c7b\u8db3\u8ff9'))},
        ),
    ]



#!/usr/bin/env python
# -*- coding:utf-8 -*-
__author__ = 'bee'

from django.conf.urls import include, url
from . import views

app_name = 'bee_django_track'
urlpatterns = [
    url(r'^test$', views.test, name='test'),
    url(r'^import_crm_fee$', views.import_crm_fee, name='import_crm_fee'),
    url(r'^record/list/(?P<user_id>[0-9]+)/$', views.RecordList.as_view(), name='record_list'),
    url(r'^record/detail/(?P<pk>[0-9]+)/$', views.RecordDetail.as_view(), name='record_detail'),
    url(r'^record/add/(?P<user_id>[0-9]+)/$', views.RecordCreate.as_view(), name='record_add'),
    url(r'^record/update/(?P<pk>[0-9]+)/$', views.RecordUpdate.as_view(), name='record_update'),
    url(r'^record/delete/(?P<pk>[0-9]+)/$', views.RecordDelete.as_view(), name='record_delete'),
]



#!/usr/bin/env python
# -*- coding:utf-8 -*-

__author__ = 'bee'
import json,pytz
from django.conf import settings
from django.apps import apps
from django.contrib.auth.models import User
from django.http import HttpResponse
from datetime import datetime
from django.conf import settings

LOCAL_TIMEZONE = pytz.timezone('Asia/Shanghai')




class JSONResponse(HttpResponse):
    def __init__(self, obj):
        if isinstance(obj, dict):
            _json_str = json.dumps(obj)
        else:
            _json_str = obj
        super(JSONResponse, self).__init__(_json_str, content_type="application/json;charset=utf-8")

# ====dt====
# 获取本地当前时间
def get_now(tz=LOCAL_TIMEZONE):
    return datetime.now(tz)



# def get_user_model():
#     if settings.COIN_USER_TABLE in ["", None]:
#         user_model = User
#     else:
#         app_name = settings.COIN_USER_TABLE.split(".")[0]
#         model_name = settings.COIN_USER_TABLE.split(".")[1]
#         app = apps.get_app_config(app_name)
#         user_model = app.get_model(model_name)
#     return user_model


# # 获取登录用户
# def get_login_user(request):
#     if settings.COIN_USER_TABLE in ["", None]:
#         return request.user
#
#     token = request.COOKIES.get('cookie_token', '')
#     # 没有登录
#     if not token:
#         return None
#
#     try:
#         user_table = get_user_model()
#         user = user_table.objects.get(token=token)
#         return user
#     except:
#         return None


# 获取用户姓名
def get_user_name(user):
    if not user:
        return None
    try:
        user_name = getattr(user, settings.USER_NAME_FIELD)
    except:
        user_name = user.username
    return user_name



#!/usr/bin/env python
# -*- coding:utf-8 -*-
__author__ = 'bee'

from .models import UserTrackRecord, ContentType


# 保存足迹
def add_user_track_record(user, content_type_identity=None, content_id=None, title=None, info=None, created_by=None):
    content_type = None
    record = UserTrackRecord()
    if content_type_identity:
        try:
            content_type = ContentType.objects.get(identity=content_type_identity)
            record.content_id = content_id
        except:
            content_type = None
    try:
        record.user = user
        record.content_type = content_type
        record.title = title
        record.info = info
        record.created_by = created_by
        record.save()
        return
    except Exception as e:
        print('bee_django_track->add_user_track_record->error:' + e.__str__())
        return



#!/usr/bin/env python
# -*- coding:utf-8 -*-
__author__ = 'zhangyue'

from django import template
from django.conf import settings
from django.shortcuts import reverse

from bee_django_track.utils import get_user_name

register = template.Library()


# 求两个值的差的绝对值
@register.filter
def get_difference_abs(a, b):
    return abs(a - b)


# 获取学生姓名，及详情链接
@register.filter
def get_name_detail(user, show_detail=True):
    if not user:
        return None
    user_name = get_user_name(user)
    if not show_detail:
        return user_name
    if settings.USER_DETAIL_EX_LINK:
        link = "<a href='" + settings.USER_DETAIL_EX_LINK + user.id.__str__() + "/'>" + user_name + "</a>"
    else:
        link = user_name
    return link


@register.simple_tag
def get_record_link(cookie_user, record):
    if record.content_type.identity == 'user_leave':
        # and cookie_user.has_perm('bee_django_user.view_user_leave_record'):
        return record.get_link
    elif record.content_type.identity == 'crm_fee':
        if cookie_user.has_perm('bee_django_crm.view_crm_preuser_fee'):
            return record.get_link
    # elif record.content_type.identity == 'crm_referral':
        # and cookie_user.has_perm('bee_django_trace.view_crm_referral'):
        # return record.get_link
    # elif record.content_type.identity == 'track_other':
        # and cookie_user.has_perm('bee_django_trace.view_track_other'):
    else:
        return record.get_link


# -*- coding:utf-8 -*-
__author__ = 'bee'

from django import forms

from .models import UserTrackRecord, ContentType


class UserTrackRecordForm(forms.ModelForm):
    content_type = forms.ModelChoiceField(queryset=ContentType.objects.filter(is_add=True), label='类型', required=True)

    class Meta:
        model = UserTrackRecord
        fields = ['content_type', 'title', 'info']



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models
from django.conf import settings
from django.core.urlresolvers import reverse


# 类别
class ContentType(models.Model):
    title = models.CharField(max_length=180, verbose_name='标题')
    identity = models.CharField(max_length=180, null=True, verbose_name='标识符', unique=True, help_text='此字段唯一')
    app_label = models.CharField(max_length=180, verbose_name='app名', null=True, blank=True)
    model = models.CharField(max_length=180, verbose_name='模块名', null=True, blank=True)
    user_field = models.CharField(max_length=180, verbose_name='用户字段名', null=True, blank=True)
    link = models.CharField(max_length=180, verbose_name='链接', null=True, blank=True)
    link_type = models.IntegerField(default=1)
    info = models.CharField(max_length=180, verbose_name='备注', null=True, blank=True)
    is_add = models.BooleanField(default=True, verbose_name='是否可添加')
    is_edit = models.BooleanField(default=True, verbose_name='是否可修改')

    class Meta:
        db_table = 'bee_django_track_content_type'
        app_label = 'bee_django_track'
        ordering = ['id']
        unique_together = ("app_label", 'model')

    def __unicode__(self):
        return self.title


# Create your models here.
class UserTrackRecord(models.Model):
    user = models.ForeignKey(settings.AUTH_USER_MODEL, verbose_name='用户')
    title = models.CharField(max_length=180, verbose_name='标题')
    info = models.TextField(verbose_name='详情',null=True,blank=True)
    content_type = models.ForeignKey(ContentType, verbose_name='类型')
    content_id = models.IntegerField(ContentType, null=True)
    created_by = models.ForeignKey(settings.AUTH_USER_MODEL, verbose_name='由谁添加', null=True,
                                   related_name='create_by_user')
    created_at = models.DateTimeField(auto_now_add=True)  # 时间

    class Meta:
        db_table = 'bee_django_track_record'
        app_label = 'bee_django_track'
        ordering = ["-created_at"]
        permissions = (
            ('add_track_other', '可以添加其他类足迹'),
            ('view_track_other', '可以查看其他类足迹'),
        )


    def __unicode__(self):
        return ("title:" + self.title)

    def get_link(self):
        if not self.content_type.link:
            return reverse("bee_django_track:record_detail", kwargs={"pk":self.pk})
        if self.content_type.link_type == 1:
            return self.content_type.link + self.content_id.__str__()
        return



# -*- coding: utf-8 -*-
from __future__ import unicode_literals
from django.views.generic import ListView, DetailView, TemplateView
from django.views.generic.edit import CreateView, UpdateView, DeleteView
from django.core.urlresolvers import reverse_lazy
from django.shortcuts import render, HttpResponse
from django.contrib.auth import get_user_model

from .models import UserTrackRecord
from .forms import UserTrackRecordForm

User = get_user_model()


# Create your views here.
def test(request):
    return


def import_crm_fee(request):
    try:
        from bee_django_crm.models import PreUserFee
        from .exports import add_user_track_record
        fee_list = PreUserFee.objects.all()
        i = 0
        j = 0
        for fee in fee_list:
            j += 1
            try:
                user = fee.preuser.userprofile.user
                if not user:
                    continue
            except:
                continue

            try:
                UserTrackRecord.objects.get(user=user, content_type__identity='crm_fee', content_id=fee.id)
                continue
            except:
                pass


            title = u"课程【" + fee.preuser_contract.contract.name + u"】缴费"
            if fee.pay_status in [2, 3, 4]:
                title += u'（' + fee.get_pay_status().decode("utf-8") + u'）'

            add_user_track_record(user=user, content_type_identity='crm_fee',
                                  content_id=fee.id, title=title, info=None, created_by=None)
            i += 1
        return HttpResponse("success:" + i.__str__() + "total:" + j.__str__())
    except Exception as e:
        return HttpResponse("error:" + e.__str__())


# record

class RecordList(ListView):
    model = UserTrackRecord
    template_name = 'bee_django_track/user/record_list.html'
    context_object_name = 'record_list'
    paginate_by = 20

    def get_user(self):
        user_id = self.kwargs["user_id"]
        user = User.objects.get(id=user_id)
        return user

    def get_context_data(self, **kwargs):
        context = super(RecordList, self).get_context_data(**kwargs)
        context["user"] = self.get_user()
        return context

    def get_queryset(self):
        user = self.get_user()
        return UserTrackRecord.objects.filter(user=user)


class RecordDetail(DetailView):
    model = UserTrackRecord
    template_name = 'bee_django_track/user/record_detail.html'
    context_object_name = 'record'

    def get_context_data(self, **kwargs):
        context = super(RecordDetail, self).get_context_data(**kwargs)
        pk = self.kwargs["pk"]
        user = UserTrackRecord.objects.get(id=pk).user
        context["user"] = user
        return context


class RecordCreate(CreateView):
    model = UserTrackRecord
    form_class = UserTrackRecordForm
    template_name = 'bee_django_track/user/record_form.html'

    def form_valid(self, form):
        form.instance.user_id = self.kwargs["user_id"]
        form.instance.created_by = self.request.user
        return super(RecordCreate, self).form_valid(form)

    def get_success_url(self):
        return reverse_lazy('bee_django_track:record_list', kwargs=self.kwargs)


class RecordUpdate(UpdateView):
    model = UserTrackRecord
    form_class = UserTrackRecordForm
    template_name = 'bee_django_track/user/record_form.html'

    def get_context_data(self, **kwargs):
        context = super(RecordUpdate, self).get_context_data(**kwargs)
        return context


class RecordDelete(DeleteView):
    model = UserTrackRecord
    success_url = reverse_lazy('bee_django_track:record_list')

    def get(self, request, *args, **kwargs):
        return self.http_method_not_allowed(request, *args, **kwargs)



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-08-10 09:46
from __future__ import unicode_literals

import bee_django_track.models
from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='ContentType',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=180, verbose_name='\u6807\u9898')),
                ('identity', models.CharField(help_text='\u6b64\u5b57\u6bb5\u552f\u4e00', max_length=180, null=True, unique=True, verbose_name='\u6807\u8bc6\u7b26')),
                ('app_label', models.CharField(blank=True, max_length=180, null=True, verbose_name='app\u540d')),
                ('model', models.CharField(blank=True, max_length=180, null=True, verbose_name='\u6a21\u5757\u540d')),
                ('user_field', models.CharField(blank=True, max_length=180, null=True, verbose_name='\u7528\u6237\u5b57\u6bb5\u540d')),
                ('link', models.CharField(blank=True, max_length=180, null=True, verbose_name='\u94fe\u63a5')),
                ('link_type', models.IntegerField(default=1)),
                ('info', models.CharField(blank=True, max_length=180, null=True, verbose_name='\u5907\u6ce8')),
                ('is_add', models.BooleanField(default=True, verbose_name='\u662f\u5426\u53ef\u6dfb\u52a0')),
                ('is_edit', models.BooleanField(default=True, verbose_name='\u662f\u5426\u53ef\u4fee\u6539')),
            ],
            options={
                'ordering': ['id'],
                'db_table': 'bee_django_track_content_type',
            },
        ),
        migrations.CreateModel(
            name='UserTrackRecord',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=180, verbose_name='\u6807\u9898')),
                ('info', models.TextField(verbose_name='\u8be6\u60c5')),
                ('content_id', models.IntegerField(null=True, verbose_name=bee_django_track.models.ContentType)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('content_type', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bee_django_track.ContentType', verbose_name='\u7c7b\u578b')),
                ('created_by', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='create_by_user', to=settings.AUTH_USER_MODEL, verbose_name='\u7531\u8c01\u6dfb\u52a0')),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL, verbose_name='\u7528\u6237')),
            ],
            options={
                'ordering': ['-created_at'],
                'db_table': 'bee_django_track_record',
            },
        ),
        migrations.AlterUniqueTogether(
            name='contenttype',
            unique_together=set([('app_label', 'model')]),
        ),
    ]
